#ifndef JTMAINWINDOW_H
#define JTMAINWINDOW_H

#include <QMainWindow>
#include <QSystemTrayIcon>
#include "jtprogressmeter.h"
#include "jttimer.h"

class QLineEdit;
class QCloseEvent;
class QTimeEdit;


class QjtMainWindow : public QMainWindow
{
Q_OBJECT

	int m_weekday;
	QTime *m_workingTimes;
	QTime *m_arrivTimes;
	QTime *m_pauseTimes;

	QjtTimer *m_timer;
	QWidget *m_centralWidget;
	QjtProgressMeter *m_progress;

	QTimeEdit *m_arrivTimeEdit;
	QTimeEdit *m_pauseTimeEdit;
	QLineEdit *m_deparLineEdit;

	QSystemTrayIcon *m_trayIcon;
	QString m_trayIconPng;

	bool m_isWorking;
	short m_saveTimeout;

public:
	QjtMainWindow();
	~QjtMainWindow();

private:
	void readSettings();
	void writeSettings();
	void setupMenus();
	void setupWidgets();
	void setupConnections();
	void setDefaultTimeEdits();
	QTime computeDepartTime( QTime arrivTime, QTime workingTime, QTime pauseTime );
	void saveData();

private slots:
	void timeout(double elapsedTimePercentage, QTime remainingTime);
	void arrivTimeChanged(const QTime &arrivTime);
	void pauseTimeChanged(const QTime &pauseTime);
	void togglePause();
	void iconActivated(QSystemTrayIcon::ActivationReason reason);
	void showSettings();
	void saveSettings( QTimeEdit *arrivTimeEdit, QTimeEdit *pauseTimeEdit, QTimeEdit *workingTimeEdit );
	void showReport();
	void showHelp();
	void about();

protected:
	void changeEvent(QEvent *event);
	void closeEvent(QCloseEvent *event);

};

#endif
