#include <QtGui>

#include "jthelpdialog.h"

/*****************************************************
 * A dialog which displays the help for jobbtime
 *****************************************************/

QjtHelpDialog::QjtHelpDialog( QWidget *parent ) : QDialog( parent )
{
	setWindowTitle( tr("Help Dialog for Jobbtime") );

	/*****************************************************
	 * Help for the main interface
	 *****************************************************/
	QTextEdit *interfaceTextEdit = new QTextEdit(this);
	interfaceTextEdit->setReadOnly(true);
	interfaceTextEdit->zoomIn( 2 );
	interfaceTextEdit->insertHtml( tr(
			" <p><br/>This is an explanation of Jobbtime's interface. The following concepts must be"
			" understood first:<br/>"
			" - <b>Working time.</b> The time you work every day, for example 8 hours."
			" <br/>"
			" - <b>Pause time.</b> The pause time not included in your working time, but the"
			" computer is kept running. Typically during your lunch break."
			" <br/>"
			" - <b>Job time.</b> The job time is the addition of your working time and pause time!"
			" </p>"

			" <p>First you have a menu bar with different menus: Settings, Report, Help and About."
			" Below this bar you find a row of 3 boxes containing respectively: <br/>"
			" - <b>your arrival time today.</b> This time can be modified but not set in the future."
			" For example if time is 9h04, you cannot set your arrival time at 9h05 or superior."
			" A message will warn you that this operation is not permitted. But you can change time"
			" to 9.03 or inferior.<br/>"
			" - <b>your pause time today.</b> Like the arrival time, it can be modified manually"
			" directly or with the small arrows. If the pause is activated (see below),"
			" this time will be updated in automatically.<br/>"
			" - <b>your departure time for today</b>. This time cannot be modified. It is calculated"
			" automatically adding pause time and working time to the arrival time."
			" </p>"

			" <p>Below those boxes you find <b>a meter</b> which indicates your time before departure."
			" The 360 degrees correspond to your job time, indicated by the countdown. The background is yellow"
			" and the foreground color is green. When you reach the overtime the foreground color becomes red."
			" If you click on the meter, you activate the pause mode. The meter becomes dark. You can see that"
			" the pause time starts to increase. Click again on the meter (or from the systray menu) and the"
			" pause mode stops.</p>"
		));

	QTextEdit *settingsTextEdit = new QTextEdit(this);
	settingsTextEdit->setReadOnly(true);
	settingsTextEdit->zoomIn( 2 );
	settingsTextEdit->insertHtml( tr(
			" <p><br/>The settings window has two different tabulations.<br/><br/>"

			" - <b>Default schedule.</b> Here you enter the default schedule for the week."
			" Arrival is your planned arrival time each day. Pause is when you are not"
			" working but the computer is kept running. Typically during lunch time, it is"
			" normally non-paid pause. Work time is the hours you have to do each"
			" day. If you don't work on a certain day you can leave the default values"
			" they won't be taken into account anyway.<br/><br/>"

			" - <b>Application.</b> Here are the applications parameters you can modify."
			" When you modify the path of the report file, be sure you have the"
			" rights to access this path."
			" </p>"
		));

	QTextEdit *reportTextEdit = new QTextEdit(this);
	reportTextEdit->setReadOnly(true);
	reportTextEdit->zoomIn( 2 );
	reportTextEdit->insertHtml( tr(
			" <p><br/>This Window displays the data recorded by Jobbtime. It is pretty clear to"
			" understand. Data are saved automatically every 5mins, when the application"
			" is closed and each time you display the report window.<br/><br/>"

			" As you can see in the window title, the data are registered in a csv file."
			" You can open this file in an external application to modify it (openOffice.org,"
			" Excel...). Each row corresponds to a line in the csv file (data separated by a comma)."
			" However it is useless to change the overtime and cumulative overtime data, respectively"
			" after the 4th and 5th comma. Those times are automatically recalculated and overwritten"
			" each time data are saved."
			" </p>"
		));

	QTextEdit *systrayTextEdit = new QTextEdit(this);
	systrayTextEdit->setReadOnly(true);
	systrayTextEdit->zoomIn( 2 );
	systrayTextEdit->insertHtml( tr(
			" <p><br/>When Jobbtime is running, a systray icon is displayed on your taskbar."
			" <br/><br/>"

			" The first use of this icon is to hide the application window. Beside its title"
			" a window always have 3 buttons: a 'minimize', a 'maximize' and a cross to close"
			" the window. Click on either minimize or maximize to hide the window. Clicking on"
			" the cross will close Jobbtime as one can expect. To make the window visible again,"
			" you can either left click on the icon or right clik and select 'restore' from the menu."
			" <br/><br/>"

			" You can also pause/resume Jobbtime from the icon. Just right click on the icon and"
			" select pause. The icon will turn dark. Click again on pause and the"
			" countdown is resumed."
			" </p>"
		));

	QTextEdit *bugTextEdit = new QTextEdit(this);
	bugTextEdit->setReadOnly(true);
	bugTextEdit->zoomIn( 2 );
	bugTextEdit->insertHtml( tr(
			" <p><br/>Jobbtime has been tested on Xfce, Gnome (Ubuntu) and Windows XP."
			" <br/><br/>"

			" The software works perfectly with Xfce. "
			" <br/><br/>"

			" With Gnome and Windows there is one known issue. The minimize or maximize"
			" buttons should reduce the application to systray. Only the maximize button"
			" has the expected behavior with Gnome, the minize button creates troubles"
			" and the application becomes impossible to close. Under Windows the same "
			" troubles appear."
			" </p>"
		));

	/*************************************************
	 * layout
	 *************************************************/
	QTabWidget *tabWidget = new QTabWidget(this);
	tabWidget->setMinimumWidth(650);
	tabWidget->setMinimumHeight(550);
	tabWidget->addTab(interfaceTextEdit, tr("&Buttons of the interface"));
	tabWidget->addTab(settingsTextEdit, tr("&Settings Window"));
	tabWidget->addTab(reportTextEdit, tr("&Report Window"));
	tabWidget->addTab(systrayTextEdit, tr("S&ystray Icon"));
	tabWidget->addTab(bugTextEdit, tr("&Limitations"));

	QPushButton* okBtt = new QPushButton(tr("Close help"));
	connect( okBtt, SIGNAL( clicked()), this, SLOT( close() ));

	/*setup the layout*/
	QVBoxLayout *vLayout = new QVBoxLayout(this);
	vLayout->addWidget( tabWidget );
		QHBoxLayout *hLayout = new QHBoxLayout();
		hLayout->addStretch();
		hLayout->addWidget( okBtt );
		hLayout->addStretch();
	vLayout->addLayout( hLayout );

}

