#include <QtGui>

#include "jtreportdialog.h"

/*****************************************************
 * A dialog which displays the default time settings
 *****************************************************/
/**
 * Constructor
 */
QjtReportDialog::QjtReportDialog( QString filename, QWidget* parent ) : QDialog( parent )
{
	setAttribute(Qt::WA_DeleteOnClose);
	setWindowTitle(QString("File: ").append(filename));
	setMinimumWidth( 700 );
	setMinimumHeight( 500 );

	/*************************************************
	 * MODEL / VIEW architecture
	 *************************************************/
	m_jtModel = new QjtStandardItemModel(20, 6, this);
	m_tableView = new QTableView(this);
	m_tableView->setEditTriggers(QAbstractItemView::NoEditTriggers);

	/*header of the table view*/
	QHeaderView *hHeader = new QHeaderView(Qt::Horizontal);
	hHeader->setMinimumSectionSize( 100 );
	hHeader->setResizeMode(QHeaderView::Stretch);

	m_tableView->setHorizontalHeader(hHeader);

	/*************************************************
	 * layout
	 *************************************************/
	QPushButton* closeBtt = new QPushButton(tr("Close this window"));
	QPushButton* closeAndQuitBtt = new QPushButton(tr("Quit Jobbtime"));

	/*setup the layout*/
	QVBoxLayout *vLayout = new QVBoxLayout(this);
	vLayout->addWidget( m_tableView );
		QHBoxLayout *hLayout = new QHBoxLayout();
		hLayout->addStretch();
		hLayout->addWidget( closeBtt );
		hLayout->addStretch();
		hLayout->addWidget( closeAndQuitBtt );
	vLayout->addLayout( hLayout );

	this->init( filename );

	connect( closeBtt, SIGNAL( clicked()), this, SLOT( close() ));
	connect( closeAndQuitBtt, SIGNAL( clicked()), qApp, SLOT( quit() ));
}


void QjtReportDialog::init( QString filename )
{
	m_tableView->setModel( m_jtModel );

	if ( m_jtModel->readReportFile(filename) )
		m_tableView->scrollTo( m_jtModel->getScrollIndex( 13 ) );
	else
		QMessageBox::critical(this, filename, tr("Error opening report file. No data to display!"));
}

