#include <QtGui>

#include "jtsettingsdialog.h"
#include "jtapplicationwidget.h"
#include "jtschedulewidget.h"

extern bool g_hideOnStart;
extern QString g_reportPath;
//extern QTime g_autocloseTime;

/*****************************************************
 * A dialog which displays the default time settings
 *****************************************************/
/**
 * Constructor
 */
QjtSettingsDialog::QjtSettingsDialog( QTime *arrivTimes, QTime *pauseTimes, QTime *workingTimes, QWidget* parent ) : QDialog( parent )
{
	setAttribute(Qt::WA_DeleteOnClose);
	setWindowTitle("Settings");

	m_schedWidget = new QjtScheduleWidget(arrivTimes, pauseTimes, workingTimes, this);
	//global variables as arguments, but Application arguments are const.
	m_appliWidget = new QjtApplicationWidget( g_hideOnStart, g_reportPath, /*g_autocloseTime,*/ this );

	QTabWidget *tabWidget = new QTabWidget(this);
	tabWidget->addTab(m_schedWidget, tr("&Default schedule"));
	tabWidget->addTab(m_appliWidget, tr("&Application"));

	QPushButton* okBtt = new QPushButton(tr("Save"));
	okBtt->setMaximumWidth(60);
	QPushButton* cancelBtt = new QPushButton(tr("Cancel"));
	cancelBtt->setMaximumWidth(60);

	/*setup the layout*/
	QVBoxLayout *vLayout = new QVBoxLayout(this);
	vLayout->addWidget( tabWidget );
		QHBoxLayout *hLayout = new QHBoxLayout();
		hLayout->addWidget( cancelBtt );
		hLayout->addStretch();
		hLayout->addWidget( okBtt );
	vLayout->addLayout( hLayout );

	connect( okBtt, SIGNAL( clicked()), this, SLOT( save_and_close() ));
	connect( cancelBtt, SIGNAL( clicked()), this, SLOT( close() ));
}


/**********************************
 * public SLOTS
 **********************************/
void QjtSettingsDialog::save_and_close()
{
	/*
	 * All the schedWidget TimeEdit are directly given to mainWindow through save(...)
	 * signal, even if they have not been modified.
	 * It is convenient since we avoid to connect each TimeEdit one by one.
	 * NOTA: m_arrivTimeEdit, m_pauseTimeEdit... are arrays of TimeEdit
	 * NOTA: save_and_close is a friend for m_schedWidget and m_appliWidget.
	 */
	emit save(	m_schedWidget->m_arrivTimeEdit,
			m_schedWidget->m_pauseTimeEdit,
			m_schedWidget->m_workingTimeEdit
		);

	/*
	 * settings recorded globally (globals here are soooo practical).
	 */
	g_hideOnStart = m_appliWidget->m_hideOnStartCheckBox->isChecked();

	//save the report file
	QString newReportPath = m_appliWidget->m_reportPathEdit->text();
	if ( g_reportPath != newReportPath )
	{
		QFile reportFile(g_reportPath);
		if ( reportFile.exists() )//it should
		{//copy and remove it
			if ( reportFile.copy( newReportPath ) && reportFile.remove())
				g_reportPath = newReportPath;
			else
				QMessageBox::critical(this, tr("Error"), tr("Can not create the file ").append(newReportPath).append(tr(". Please check your access rights.")));
		}
	}
	
	//g_autocloseTime = m_appliWidget->m_autocloseEdit->time();

	close();
}

